@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008, 2009 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -16,9 +16,9 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 APP_NAME = 'Mobius Forensic Toolkit'
-APP_VERSION = '${version}'
+APP_VERSION = '0.5.6'
 APP_TITLE = 'Mobius v%s' % APP_VERSION
-APP_DATADIR='${install_data}'
+APP_DATADIR='/tmp/mobius-test/share/mobiusft'
 
 import os.path
 
@@ -26,5 +26,5 @@ import os.path
 # @brief Return path to file/directory inside DATADIR
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 def get_data_path (*args):
-  return os.path.join (APP_DATADIR, 'data', *args)
+  return os.path.join (APP_DATADIR, *args)
 
